==> quarkus-core-2.4.1.Final-sources.jar: io/quarkus/runtime/logging/ConsoleConfig$$accessor.java <==
package io.quarkus.runtime.logging;
public final class ConsoleConfig$$accessor {
    private ConsoleConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enable(Object __instance) {
        return ((ConsoleConfig)__instance).enable;
    }
    @SuppressWarnings("unchecked")
    public static void set_enable(Object __instance, boolean enable) {
        ((ConsoleConfig)__instance).enable = enable;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_stderr(Object __instance) {
        return ((ConsoleConfig)__instance).stderr;
    }
    @SuppressWarnings("unchecked")
    public static void set_stderr(Object __instance, boolean stderr) {
        ((ConsoleConfig)__instance).stderr = stderr;
    }
    @SuppressWarnings("unchecked")
    public static Object get_format(Object __instance) {
        return ((ConsoleConfig)__instance).format;
    }
    @SuppressWarnings("unchecked")
    public static void set_format(Object __instance, Object format) {
        ((ConsoleConfig)__instance).format = (String)format;
    }
    @SuppressWarnings("unchecked")
    public static Object get_level(Object __instance) {
        return ((ConsoleConfig)__instance).level;
    }
    @SuppressWarnings("unchecked")
    public static void set_level(Object __instance, Object level) {
        ((ConsoleConfig)__instance).level = (java.util.logging.Level)level;
    }
    @SuppressWarnings("unchecked")
    public static int get_darken(Object __instance) {
        return ((ConsoleConfig)__instance).darken;
    }
    @SuppressWarnings("unchecked")
    public static void set_darken(Object __instance, int darken) {
        ((ConsoleConfig)__instance).darken = darken;
    }
    @SuppressWarnings("unchecked")
    public static Object get_async(Object __instance) {
        return ((ConsoleConfig)__instance).async;
    }
    @SuppressWarnings("unchecked")
    public static void set_async(Object __instance, Object async) {
        ((ConsoleConfig)__instance).async = (AsyncConfig)async;
    }
}

==> quarkus-core-3.2.9.Final-sources.jar: io/quarkus/runtime/logging/ConsoleConfig$$accessor.java <==
package io.quarkus.runtime.logging;
public final class ConsoleConfig$$accessor {
    private ConsoleConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enable(Object __instance) {
        return ((ConsoleConfig)__instance).enable;
    }
    @SuppressWarnings("unchecked")
    public static void set_enable(Object __instance, boolean enable) {
        ((ConsoleConfig)__instance).enable = enable;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_stderr(Object __instance) {
        return ((ConsoleConfig)__instance).stderr;
    }
    @SuppressWarnings("unchecked")
    public static void set_stderr(Object __instance, boolean stderr) {
        ((ConsoleConfig)__instance).stderr = stderr;
    }
    @SuppressWarnings("unchecked")
    public static Object get_format(Object __instance) {
        return ((ConsoleConfig)__instance).format;
    }
    @SuppressWarnings("unchecked")
    public static void set_format(Object __instance, Object format) {
        ((ConsoleConfig)__instance).format = (String)format;
    }
    @SuppressWarnings("unchecked")
    public static Object get_level(Object __instance) {
        return ((ConsoleConfig)__instance).level;
    }
    @SuppressWarnings("unchecked")
    public static void set_level(Object __instance, Object level) {
        ((ConsoleConfig)__instance).level = (java.util.logging.Level)level;
    }
    @SuppressWarnings("unchecked")
    public static int get_darken(Object __instance) {
        return ((ConsoleConfig)__instance).darken;
    }
    @SuppressWarnings("unchecked")
    public static void set_darken(Object __instance, int darken) {
        ((ConsoleConfig)__instance).darken = darken;
    }
    @SuppressWarnings("unchecked")
    public static Object get_filter(Object __instance) {
        return ((ConsoleConfig)__instance).filter;
    }
    @SuppressWarnings("unchecked")
    public static void set_filter(Object __instance, Object filter) {
        ((ConsoleConfig)__instance).filter = (java.util.Optional<String>)filter;
    }
    @SuppressWarnings("unchecked")
    public static Object get_async(Object __instance) {
        return ((ConsoleConfig)__instance).async;
    }
    @SuppressWarnings("unchecked")
    public static void set_async(Object __instance, Object async) {
        ((ConsoleConfig)__instance).async = (AsyncConfig)async;
    }
}
